SNAPSHOT_TIMESTAMP_SQL = """
{% snapshot snapshot %}
    {{ config(
        target_database=database,
        target_schema=schema,
        unique_key='id',
        strategy='timestamp',
        updated_at='updated_at',
        invalidate_hard_deletes=True,
    ) }}
    select * from {{ ref('fact') }}
{% endsnapshot %}
"""


SNAPSHOT_CHECK_SQL = """
{% snapshot snapshot %}
    {{ config(
        target_database=database,
        target_schema=schema,
        unique_key='id',
        strategy='check',
        check_cols=['email'],
    ) }}
    select * from {{ ref('fact') }}
{% endsnapshot %}
"""



# bool_or

seeds__data_bool_or_csv = """key_column,val1,val2
abc,1,1
abc,1,0
def,1,0
hij,1,1
hij,1,
klm,1,0
klm,1,
"""


seeds__data_bool_or_expected_csv = """key_column,value
abc,true
def,false
hij,true
klm,false
"""


models__test_bool_or_sql = """
with data as (

    select * from {{ ref('data_bool_or') }}

),

data_output as (

    select * from {{ ref('data_bool_or_expected') }}

),

calculate as (

    select
        key_column,
        {{ bool_or('val1 = val2') }} as value
    from data
    group by key_column

)

select
    calculate.value as actual,
    data_output.value as expected
from calculate
left join data_output
on calculate.key_column = data_output.key_column
"""


models__test_bool_or_yml = """
version: 2
models:
  - name: test_bool_or
    tests:
      - assert_equal:
          actual: actual
          expected: expected
"""



import pytest
from dbt.tests.adapter.utils.data_types.base_data_type_macro import BaseDataTypeMacro

models__expected_sql = """
select 9223372036854775800 as bigint_col
""".lstrip()

models__actual_sql = """
select cast('9223372036854775800' as {{ type_bigint() }}) as bigint_col
"""


class BaseTypeBigInt(BaseDataTypeMacro):
    @pytest.fixture(scope="class")
    def models(self):
        return {
            "expected.sql": models__expected_sql,
            "actual.sql": self.interpolate_macro_namespace(models__actual_sql, "type_bigint"),
        }


class TestTypeBigInt(BaseTypeBigInt):
    pass



import pytest
from dbt.tests.adapter.utils.base_utils import BaseUtils
from dbt.tests.adapter.utils.fixture_datediff import (
    seeds__data_datediff_csv,
    models__test_datediff_sql,
    models__test_datediff_yml,
)


class BaseDateDiff(BaseUtils):
    @pytest.fixture(scope="class")
    def seeds(self):
        return {"data_datediff.csv": seeds__data_datediff_csv}

    @pytest.fixture(scope="class")
    def models(self):
        return {
            "test_datediff.yml": models__test_datediff_yml,
            "test_datediff.sql": self.interpolate_macro_namespace(
                models__test_datediff_sql, "datediff"
            ),
        }


class TestDateDiff(BaseDateDiff):
    pass



import pytest
from dbt.tests.adapter.utils.data_types.base_data_type_macro import BaseDataTypeMacro

seeds__expected_csv = """timestamp_col
2021-01-01 01:01:01
""".lstrip()

# need to explicitly cast this to avoid it being a DATETIME on BigQuery
# (but - should it actually be a DATETIME, for consistency with other dbs?)
seeds__expected_yml = """
version: 2
seeds:
  - name: expected
    config:
      column_types:
        timestamp_col: timestamp
"""

models__actual_sql = """
select cast('2021-01-01 01:01:01' as {{ type_timestamp() }}) as timestamp_col
"""


class BaseTypeTimestamp(BaseDataTypeMacro):
    @pytest.fixture(scope="class")
    def seeds(self):
        return {
            "expected.csv": seeds__expected_csv,
            "expected.yml": seeds__expected_yml,
        }

    @pytest.fixture(scope="class")
    def models(self):
        return {
            "actual.sql": self.interpolate_macro_namespace(models__actual_sql, "type_timestamp")
        }


class TestTypeTimestamp(BaseTypeTimestamp):
    pass



import pytest
from dbt.tests.adapter.utils.base_utils import BaseUtils
from dbt.tests.adapter.utils.fixture_bool_or import (
    seeds__data_bool_or_csv,
    seeds__data_bool_or_expected_csv,
    models__test_bool_or_sql,
    models__test_bool_or_yml,
)


class BaseBoolOr(BaseUtils):
    @pytest.fixture(scope="class")
    def seeds(self):
        return {
            "data_bool_or.csv": seeds__data_bool_or_csv,
            "data_bool_or_expected.csv": seeds__data_bool_or_expected_csv,
        }

    @pytest.fixture(scope="class")
    def models(self):
        return {
            "test_bool_or.yml": models__test_bool_or_yml,
            "test_bool_or.sql": self.interpolate_macro_namespace(
                models__test_bool_or_sql, "bool_or"
            ),
        }


class TestBoolOr(BaseBoolOr):
    pass
